/*
 * @(#)Version-template.java	1.6 03/01/23
 *
 * Copyright 2003 Sun Microsystems, Inc. All rights reserved.
 * SUN PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */

package sun.misc;
import java.io.PrintStream;

public class Version {

    private static final String java_version =
		"1.5.0_11";
	
    private static final String java_runtime_name =
		"Java(TM) 2 Runtime Environment, Standard Edition";

    private static final String java_runtime_version =
		"1.5.0_11-b03 20070511";

    static {
	init();
    }

    public static void init() {
	System.setProperty("java.version", java_version);
	System.setProperty("java.runtime.version", java_runtime_version);
	System.setProperty("java.runtime.name", java_runtime_name);
    }

    /**
     * In case you were wondering this method is called by java -version.
     * Sad that it prints to stderr; would be nicer if default printed on
     * stdout.
     */
    public static void print() {
		print(System.err);
    }

    /**
     * Give a stream, it will print version info on it.
     */
    public static void print(PrintStream ps) {
    	/*
    	 * Sun's 'java -version' print method. 
    	 */
    	
		ps.println("java version \"" + java_version + "\"");

		/* Second line: runtime version (ie, libraries). */
		ps.println(java_runtime_name + " (IBM build " +
				   java_runtime_version + ")");

		/* Third line: JVM information. */
		String java_vm_name    = (String)System.getProperty("java.vm.name");
		String java_vm_version = (String)System.getProperty("java.vm.version");
		String java_vm_info    = (String)System.getProperty("java.vm.info");
		ps.println(java_vm_name + " (build " + java_vm_version + ", " +
			   java_vm_info + ")");
		
		try {
			ps.println(com.ibm.rmi.util.Version.asString());
		} catch ( Error e ) {
		}
		
		//ps.println(com.ibm.rmi.util.Version.asString());
		
		String [] ibm_xml_classes = {
			"sun.misc.Version",
			"org.apache.xalan.Version",
			"org.apache.xmlcommons.Version",
			"org.apache.xerces.impl.Version"
		};
		
		String [] ibm_xml_paths = {
			"sun/misc/Version.class",
			"org/apache/xalan/Version.class",
			"org/apache/xmlcommons/Version.class",
			"org/apache/xerces/impl/Version.class"
		};
		ClassLoader cl = ClassLoader.getSystemClassLoader();
		boolean is_ibm_class = false;
		for ( int i = 0; i < ibm_xml_classes.length; i++ ) {
			is_ibm_class = false;
			java.net.URL file = cl.getResource(ibm_xml_paths[i]);
			if ( file != null ) {
				if ( file.toString().indexOf("endorsed/ibm") > 0 ) {
					is_ibm_class = true;
				}
			}
			
			try {	
				Class ibm_xml_class_obj = Class.forName(ibm_xml_classes[i]);
				Object xml_obj = ibm_xml_class_obj.newInstance();
				
				if ( xml_obj instanceof org.apache.xalan.Version ) {
					ps.println(
						(is_ibm_class? "IBM " : "") +
						"XML build " + org.apache.xalan.Version.getVersion()
					);
				}
				
				if ( xml_obj instanceof org.apache.xmlcommons.Version ) {
					ps.println(
						(is_ibm_class? "IBM " : "") +
						"XML build " + org.apache.xmlcommons.Version.getVersion()
					);
				}
				
				if ( xml_obj instanceof org.apache.xerces.impl.Version ) {
					ps.println(
						(is_ibm_class? "IBM " : "") +
						"XML build " + org.apache.xerces.impl.Version.getVersion()
					);
				}

			} catch ( NoClassDefFoundError e) {
			} catch ( ClassNotFoundException e) {
			} catch ( InstantiationException e) {
			} catch ( IllegalAccessException e ) {
			}
		}
    }

}

// Help Emacs a little because this file doesn't end in .java.
//
// Local Variables: ***
// mode: java ***
// End: ***
